<!--
SPDX-FileCopyrightText: 2026 Helge Eichhorn <git@helgeeichhorn.de>

SPDX-License-Identifier: MPL-2.0
-->

# lox-core

Common data types and utilities for the [Lox](https://github.com/lox-space/lox) ecosystem,
including Cartesian coordinates and trajectory types.

Part of [Lox – Oxidized Astrodynamics](https://github.com/lox-space/lox).
